summaryrefslogtreecommitdiffstats
path: root/scripts/automation/trex_control_plane/client_utils
diff options
context:
space:
mode:
authorYaroslav Brustinov <ybrustin@cisco.com>2016-02-10 16:32:54 +0200
committerYaroslav Brustinov <ybrustin@cisco.com>2016-02-10 16:32:54 +0200
commit0f03cc467be9c0b37310b7e2a589a86a1771c96f (patch)
tree32983679b9033b0379d2036740b796d8fe557c3f /scripts/automation/trex_control_plane/client_utils
parenta69c4dd80e88b6fb4ebfae8d84366b11561d7660 (diff)
update hltapi + functional regression + remove old packet_builder tests
Diffstat (limited to 'scripts/automation/trex_control_plane/client_utils')
-rwxr-xr-xscripts/automation/trex_control_plane/client_utils/general_utils.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/scripts/automation/trex_control_plane/client_utils/general_utils.py b/scripts/automation/trex_control_plane/client_utils/general_utils.py
index 3d55bc3e..9a510ec5 100755
--- a/scripts/automation/trex_control_plane/client_utils/general_utils.py
+++ b/scripts/automation/trex_control_plane/client_utils/general_utils.py
@@ -90,9 +90,11 @@ def id_count_gen():
yield return_id
return_id += 1
-# try to get integer from input, return None in case of fail
-def get_integer(input):
+# try to get number from input, return None in case of fail
+def get_number(input):
try:
+ if type(input) in (int, long):
+ return input
return int(input)
except:
return None